@@ -1,4 +1,4 @@
-__version__ = '4.7.3'
+__version__ = '4.11.1'
 
 
 def setup(app):
@@ -13,4 +13,8 @@ def setup(app):
     from . import directives
 
     directives.setup(app)
-    return {'version': __version__}
+    return {
+        'version': __version__,
+        'parallel_read_safe': True,
+        'parallel_write_safe': True
+    }
