@@ -72,6 +72,7 @@ class DomainDirectiveFactory(object):
         'interface': (DoxyCPPClassObject, 'interface'),
         'function': (cpp.CPPFunctionObject, 'function'),
         'friend': (cpp.CPPFunctionObject, 'function'),
+        'signal': (cpp.CPPFunctionObject, 'function'),
         'slot': (cpp.CPPFunctionObject, 'function'),
         'enum': (cpp.CPPTypeObject, 'type'),
         'typedef': (cpp.CPPTypeObject, 'type'),
@@ -170,11 +171,12 @@ def get_param_decl(param):
     def to_string(node):
         """Convert Doxygen node content to a string."""
         result = []
-        for p in node.content_:
-            value = p.value
-            if not isinstance(value, six.text_type):
-                value = value.valueOf_
-            result.append(value)
+        if node is not None:
+            for p in node.content_:
+                value = p.value
+                if not isinstance(value, six.text_type):
+                    value = value.valueOf_
+                result.append(value)
         return ' '.join(result)
 
     param_type = to_string(param.type_)
@@ -547,7 +549,7 @@ class SphinxRenderer(object):
         ("public-func", "Public Functions"),
         ("public-attrib", "Public Members"),
         ("public-slot", "Public Slots"),
-        ("signal", "Signal"),
+        ("signal", "Signals"),
         ("dcop-func", "DCOP Function"),
         ("property", "Property"),
         ("event", "Event"),
@@ -798,7 +800,7 @@ class SphinxRenderer(object):
                 rst_node = self.node_factory.displaymath()
 
             # Or multiline
-            if latex.startswith("\[") and latex.endswith("\]"):
+            if latex.startswith("\\[") and latex.endswith("\\]"):
                 latex = latex[2:-2:]
 
             # Here we steal the core of the mathbase "math" directive handling code from:
@@ -1236,7 +1238,7 @@ class SphinxRenderer(object):
 
     def dispatch_memberdef(self, node):
         """Dispatch handling of a memberdef node to a suitable visit method."""
-        if node.kind in ("function", "slot") or \
+        if node.kind in ("function", "signal", "slot") or \
                 (node.kind == 'friend' and node.argsstring):
             return self.visit_function(node)
         if node.kind == "enum":
